;; Generated package description from autocrypt.el  -*- no-byte-compile: t -*-
(define-package "autocrypt" "0.4.1.0.20230407.142425" "Autocrypt implementation" '((emacs "24.3")) :commit "5fc15d64437c3531b5d61d73c5b9eb19603b2a17" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "~pkal/public-inbox@lists.sr.ht") :keywords '("comm") :url "https://git.sr.ht/~pkal/autocrypt")
